# fsqpy
Python-based FSQ API designed for transferring data to an FSQ server.
It also includes a straightforward console client for demonstrating how to use the API.

## Installation
```pip3 install pyfsq```

## Requirements
### Python
* Python >= 3.7

